@@ -16,15 +16,15 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
-from google.api_core.client_options import ClientOptions
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
+from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -33,12 +33,14 @@ except AttributeError:  # pragma: NO COVER
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
+from google.protobuf import empty_pb2  # type: ignore
+
 from google.cloud.vpcaccess_v1.services.vpc_access_service import pagers
 from google.cloud.vpcaccess_v1.types import vpc_access
-from google.protobuf import empty_pb2  # type: ignore
-from .transports.base import VpcAccessServiceTransport, DEFAULT_CLIENT_INFO
-from .transports.grpc_asyncio import VpcAccessServiceGrpcAsyncIOTransport
+
 from .client import VpcAccessServiceClient
+from .transports.base import DEFAULT_CLIENT_INFO, VpcAccessServiceTransport
+from .transports.grpc_asyncio import VpcAccessServiceGrpcAsyncIOTransport
 
 
 class VpcAccessServiceAsyncClient:
@@ -222,14 +224,13 @@ class VpcAccessServiceAsyncClient:
         r"""Creates a Serverless VPC Access connector, returns an
         operation.
 
-
         .. code-block:: python
 
             from google.cloud import vpcaccess_v1
 
-            def sample_create_connector():
+            async def sample_create_connector():
                 # Create a client
-                client = vpcaccess_v1.VpcAccessServiceClient()
+                client = vpcaccess_v1.VpcAccessServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = vpcaccess_v1.CreateConnectorRequest(
@@ -242,7 +243,7 @@ class VpcAccessServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -322,7 +323,12 @@ class VpcAccessServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -347,14 +353,13 @@ class VpcAccessServiceAsyncClient:
         r"""Gets a Serverless VPC Access connector. Returns NOT_FOUND if the
         resource does not exist.
 
-
         .. code-block:: python
 
             from google.cloud import vpcaccess_v1
 
-            def sample_get_connector():
+            async def sample_get_connector():
                 # Create a client
-                client = vpcaccess_v1.VpcAccessServiceClient()
+                client = vpcaccess_v1.VpcAccessServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = vpcaccess_v1.GetConnectorRequest(
@@ -362,7 +367,7 @@ class VpcAccessServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_connector(request=request)
+                response = await client.get_connector(request=request)
 
                 # Handle the response
                 print(response)
@@ -422,7 +427,12 @@ class VpcAccessServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -442,9 +452,9 @@ class VpcAccessServiceAsyncClient:
 
             from google.cloud import vpcaccess_v1
 
-            def sample_list_connectors():
+            async def sample_list_connectors():
                 # Create a client
-                client = vpcaccess_v1.VpcAccessServiceClient()
+                client = vpcaccess_v1.VpcAccessServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = vpcaccess_v1.ListConnectorsRequest(
@@ -455,7 +465,7 @@ class VpcAccessServiceAsyncClient:
                 page_result = client.list_connectors(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -516,12 +526,20 @@ class VpcAccessServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListConnectorsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -539,14 +557,13 @@ class VpcAccessServiceAsyncClient:
         r"""Deletes a Serverless VPC Access connector. Returns NOT_FOUND if
         the resource does not exist.
 
-
         .. code-block:: python
 
             from google.cloud import vpcaccess_v1
 
-            def sample_delete_connector():
+            async def sample_delete_connector():
                 # Create a client
-                client = vpcaccess_v1.VpcAccessServiceClient()
+                client = vpcaccess_v1.VpcAccessServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = vpcaccess_v1.DeleteConnectorRequest(
@@ -558,7 +575,7 @@ class VpcAccessServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -631,7 +648,12 @@ class VpcAccessServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
